
CREATE TABLE `kw_leave_office` (
  `office_id` tinyint(3) unsigned NOT NULL AUTO_INCREMENT COMMENT '處室編號',
  `office_title` varchar(10) NOT NULL DEFAULT '' COMMENT '審核職稱',
  `office_sort` tinyint(2) unsigned NOT NULL COMMENT '處室順序',
  `office_isenable` enum('1','0') NOT NULL DEFAULT '1' COMMENT '是否啟用',
  PRIMARY KEY (`office_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `kw_leave_office` (`office_id`, `office_title`, `office_sort`, `office_isenable`) VALUES
(1,	'教務處',	1,	'1'),
(2,	'學務處',	2,	'1'),
(3,	'總務處',	3,	'0'),
(4,	'輔導室',	4,	'0'),
(5,	'人事室',	5,	'1'),
(6,	'校長室',	6,	'1');


CREATE TABLE `kw_leave_cate` (
  `cate_id` tinyint(3) unsigned NOT NULL AUTO_INCREMENT COMMENT '假別編號',
  `cate_title` varchar(10) NOT NULL DEFAULT '' COMMENT '假別名稱',
  `cate_sort` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '排序',
  `cate_isenable` enum('1','0') CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '1' COMMENT '啟用',
  PRIMARY KEY (`cate_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `kw_leave_cate` (`cate_id`, `cate_title`, `cate_sort`, `cate_isenable`) VALUES
(1,	'事假',	1,	'1'),
(2,	'病假',	2,	'1'),
(3,	'公假',	3,	'1'),
(4,	'喪假', 4,	'1'),
(5,	'生理假',	5,	'1'),
(6,	'防疫假',	6,	'1');



CREATE TABLE `kw_leave_process` (
  `process_id` smallint(6) unsigned NOT NULL AUTO_INCREMENT COMMENT '流程編號',
  `office_id` tinyint(3) unsigned NOT NULL COMMENT '處室ID',
  `process_title` varchar(12) NOT NULL DEFAULT '' COMMENT '審核職稱',
  `process_uid` smallint(6) unsigned NOT NULL COMMENT '審核者',
  `process_backup_uid` smallint(6) unsigned DEFAULT NULL COMMENT '職代者',
  `process_sort` tinyint(2) unsigned NOT NULL DEFAULT '1' COMMENT '流程排序',
  `process_isenable` enum('1','0') NOT NULL DEFAULT '1' COMMENT '是否啟用',
  PRIMARY KEY (`process_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE TABLE `kw_leave_book` (
  `book_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '請假編號',
  `book_title` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '請假班級',
  `book_year` smallint(6) unsigned NOT NULL COMMENT '學年度',
  `cate_id` tinyint(3) unsigned NOT NULL COMMENT '假別ID',
  `stu_id` varchar(10) NOT NULL COMMENT '請假者學號或openid',
  `book_json` text NOT NULL COMMENT 'json請假事由',
  `book_number` float unsigned NOT NULL COMMENT '請假天數',
  `book_dt_start` datetime NOT NULL COMMENT '起始日期',
  `book_dt_end` datetime NOT NULL COMMENT '結束日期',
  `book_dt_update` datetime NOT NULL COMMENT '申請日期',
  `book_isenable` enum('1','0') CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '1' COMMENT '是否申請',
  `book_sort` tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否開始簽核',
  `book_isresult` enum('1','0') CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '0' COMMENT '是否准假',
  `book_isfinish` enum('1','0') NOT NULL DEFAULT '0' COMMENT '是否完成請假',
  PRIMARY KEY (`book_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE TABLE `kw_leave_img` (
  `img_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '簽名編號',
  `book_id` mediumint(8) unsigned NOT NULL COMMENT '假單編號',
  `img_type` varchar(8) NOT NULL COMMENT '影像類型',
  `img_content` text NOT NULL COMMENT '影像內容',
  `img_date` datetime DEFAULT NULL COMMENT '簽名時間',
  PRIMARY KEY (`img_id`),
  KEY `book_id` (`book_id`),
  CONSTRAINT `xx_kw_leave_img_ibfk_2` FOREIGN KEY (`book_id`) REFERENCES `xx_kw_leave_book` (`book_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE TABLE `kw_leave_sign` (
  `sign_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '簽核編號',
  `book_id` mediumint(8) unsigned NOT NULL COMMENT '請假單ID',
  `sign_uid` smallint(6) unsigned NOT NULL COMMENT '簽核者UID',
  `sign_sort` tinyint(2) unsigned NOT NULL COMMENT '流程序',
  `sign_time` datetime DEFAULT NULL COMMENT '簽核時間',
  `sign_year` tinyint(3) unsigned NOT NULL COMMENT '簽核學年',
  `sign_isagree` enum('0','1') CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '1' COMMENT '是否准假',
  `sign_code` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '簽核碼',
  `sign_json` text NOT NULL COMMENT '簽核json',
  PRIMARY KEY (`sign_id`),
  KEY `book_id` (`book_id`),
  CONSTRAINT `xx_kw_leave_sign_ibfk_1` FOREIGN KEY (`book_id`) REFERENCES `xx_kw_leave_book` (`book_id`) ON DELETE CASCADE ON UPDATE RESTRICT
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE TABLE `kw_leave_class` (
  `class_id` smallint(5) unsigned NOT NULL COMMENT '班級ID',
  `class_title` varchar(8) NOT NULL COMMENT '班級名稱',
  `class_grade` tinyint(2) unsigned NOT NULL COMMENT '年級',
  `class_class` tinyint(3) unsigned NOT NULL COMMENT '班級',
  `class_num` tinyint(3) unsigned NOT NULL COMMENT '學生數',
  `class_teacher` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '相關資訊',
  `class_sort` tinyint(2) unsigned NOT NULL COMMENT '排序',
  `class_isenable` enum('1','0') CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '啟用',
  `class_teacher_uid` smallint(6) unsigned NOT NULL COMMENT '導師uid',
  PRIMARY KEY (`class_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE TABLE `kw_leave_stu` (
  `stu_sn` mediumint(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '流水號',
  `stu_id` varchar(10) NOT NULL COMMENT '學號或openid',
  `class_id` smallint(5) unsigned NOT NULL COMMENT '班級編號',
  `stu_title` varchar(6) NOT NULL COMMENT '學生姓名',
  `stu_num` tinyint(2) unsigned NOT NULL COMMENT '學生座號',
  `stu_uid` varchar(10) NOT NULL COMMENT '身分證字號',
  `stu_year` tinyint(3) unsigned NOT NULL COMMENT '入學年',
  `stu_grade` tinyint(2) unsigned NOT NULL COMMENT '學生年級',
  `stu_class` tinyint(3) unsigned NOT NULL COMMENT '學生班級',
  `stu_total` float unsigned DEFAULT NULL COMMENT '本學年請假總天數',
  `stu_json` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '相關資訊',
  PRIMARY KEY (`stu_sn`),
  UNIQUE KEY `stu_id` (`stu_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


